from liji.ext._liji import inspect
import ujson
import json
from datetime import datetime

COUNT = 100000
jsondata = open('../fixtures/reallybigone.json').read()


def with_liji():
    inspect(jsondata, ["events", "picture"])


def with_ujson():
    parsed = ujson.loads(jsondata)
    [ev.get('user', {}).get('picture', None) for ev in parsed['events']]


def with_json():
    parsed = json.loads(jsondata)
    [ev.get('user', {}).get('picture', None) for ev in parsed['events']]


test_funcs = [
    with_liji,
    with_ujson,
    # with_json,
]

for func in test_funcs:
    t0 = datetime.now()
    for i in xrange(COUNT):
        func()
    t = datetime.now() - t0
    print "%s - %s" % (func.__name__, t)



# -*- coding: utf-8 -*-

import os
from setuptools import setup, Extension


if not 'CFLAGS' in os.environ:
    os.environ['CFLAGS'] = ''

setup(
    name='liji',
    version='0.1.1',
    description="liji",
    keywords='json',
    author='globo.com',
    author_email='cezarsa@gmail.com',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: MacOS',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 2.7'
    ],
    packages=['liji'],
    package_dir={"liji": "liji"},
    include_package_data=True,
    ext_modules=[
        Extension('liji.ext._liji',
                  ['liji/ext/_liji.c', 'lib/liji.c'],
                  include_dirs=['lib'],
                  depends=['setup.py', 'liji/ext/_liji.c', 'lib/liji.c', 'lib/liji.h'],
                  extra_compile_args=['-Wall', '-Wextra', '-Werror', '-Wno-unused-parameter'])
    ]
)
